@@ -447,7 +447,8 @@ class AustinStats:
     processes: Dict[ProcessId, ProcessStats] = field(default_factory=dict)
     _lock: Lock = field(default_factory=Lock, compare=False)
 
-    def __deepcopy__(self, memo={}):
+    def __deepcopy__(self, memo: Optional[Dict[Any, Any]] = None) -> "AustinStats":
+        """Make a deep copy of this AustinStats object."""
         state = dict(self.__dict__)
         del state["_lock"]
 
